@@ -1,6 +1,9 @@
+import logging
+
 from MSApi.exceptions import *
 from MSApi.properties import *
 import requests
+import urllib.parse
 
 from datetime import datetime
 
@@ -23,7 +26,7 @@ def string_to_datetime(string):
 def caching(f):
     cache = [None]
 
-    def decorate(cls, cached=False, *args, **kwargs):
+    def decorate(cls, *args, cached=False, **kwargs):
         if cached is True:
             if cache[0] is None:
                 cache[0] = list(f(cls, *args, **kwargs))
@@ -40,6 +43,7 @@ class Authorizer:
     def login(cls, login: str, password: str):
         import base64
         auch_base64 = base64.b64encode(f"{login}:{password}".encode('utf-8')).decode('utf-8')
+
         response = requests.post(f"{ms_url}/security/token",
                                  headers={"Authorization": f"Basic {auch_base64}"})
         error_handler(response, 201)
@@ -76,7 +80,8 @@ class MSLowApi:
     @classmethod
     # @check_login
     def auch_post(cls, request, **kwargs):
-        # print(f"POST: {request}")
+        logging.debug(f"MSApi POST: {request}")
+        request = urllib.parse.quote(request)
         return requests.post(f"{ms_url}/{request}",
                              headers={"Authorization": f"Bearer {cls.__authorizer.token}",
                                       "Content-Type": "application/json"},
@@ -84,12 +89,14 @@ class MSLowApi:
 
     @classmethod
     def auch_get(cls, request, **kwargs):
-        # print(f"GET: {request}")
+        logging.debug(f"MSApi GET: {request}")
+        urllib.parse.quote(request)
         return cls._auch_get_by_href(f"{ms_url}/{request}", **kwargs)
 
     @classmethod
     def auch_put(cls, request, **kwargs):
-        # print(f"GET: {request}")
+        logging.debug(f"MSApi PUT: {request}")
+        request = urllib.parse.quote(request)
         return requests.put(f"{ms_url}/{request}",
                             headers={"Authorization": f"Bearer {cls.__authorizer.token}",
                                      "Content-Type": "application/json"},
