@@ -1,11 +1,14 @@
 from typing import Optional
 
 from MSApi.Assortment import Assortment
-from MSApi.mixin import AttributeMixin
+from MSApi.mixin import AttributeMixin, SalePricesMixin
 from MSApi.mixin import ProductfolderMixin
 
 
-class Service(Assortment, AttributeMixin, ProductfolderMixin):
+class Service(Assortment,
+              AttributeMixin,
+              ProductfolderMixin,
+              SalePricesMixin):
 
     _type_name = 'service'
 
